@@ -59,7 +59,7 @@ const ApplicationMenuItem = new Lang.Class({
         this.addActor(this._iconBin);
 
         let appLabel = new St.Label({ text: app.get_name() });
-        this.addActor(appLabel, { span: -1, expand: true });
+        this.addActor(appLabel, { expand: true });
         this.actor.label_actor = appLabel;
 
         let textureCache = St.TextureCache.get_default();
@@ -227,24 +227,23 @@ const ApplicationsMenu = new Lang.Class({
     Name: 'ApplicationsMenu',
     Extends: PopupMenu.PopupMenu,
 
-    _init: function(sourceActor, arrowAlignment, arrowSide, button, hotCorner) {
+    _init: function(sourceActor, arrowAlignment, arrowSide, button) {
         this.parent(sourceActor, arrowAlignment, arrowSide);
         this._button = button;
-        this._hotCorner = hotCorner;
     },
 
     open: function(animate) {
-        this._hotCorner.setBarrierSize(0);
-        if (this._hotCorner.actor) // fallback corner
-            this._hotCorner.actor.hide();
+        this._button.hotCorner.setBarrierSize(0);
+        if (this._button.hotCorner.actor) // fallback corner
+            this._button.hotCorner.actor.hide();
         this.parent(animate);
     },
 
     close: function(animate) {
         let size = Main.layoutManager.panelBox.height;
-        this._hotCorner.setBarrierSize(size);
-        if (this._hotCorner.actor) // fallback corner
-            this._hotCorner.actor.show();
+        this._button.hotCorner.setBarrierSize(size);
+        if (this._button.hotCorner.actor) // fallback corner
+            this._button.hotCorner.actor.show();
         this.parent(animate);
     },
 
@@ -265,9 +264,8 @@ const ApplicationsButton = new Lang.Class({
 
     _init: function() {
         this.parent(1.0, null, false);
-        this._hotCorner = Main.layoutManager.hotCorners[Main.layoutManager.primaryIndex];
 
-        this.setMenu(new ApplicationsMenu(this.actor, 1.0, St.Side.TOP, this, this._hotCorner));
+        this.setMenu(new ApplicationsMenu(this.actor, 1.0, St.Side.TOP, this));
         Main.panel.menuManager.addMenu(this.menu);
 
         // At this moment applications menu is not keyboard navigable at
@@ -310,6 +308,10 @@ const ApplicationsButton = new Lang.Class({
         }));
     },
 
+    get hotCorner() {
+        return Main.layoutManager.hotCorners[Main.layoutManager.primaryIndex];
+    },
+
     _createVertSeparator: function() {
         let separator = new St.DrawingArea({ style_class: 'calendar-vertical-separator',
                                              pseudo_class: 'highlighted' });
@@ -424,7 +426,7 @@ const ApplicationsButton = new Lang.Class({
         this.leftBox = new St.BoxLayout({ vertical: true });
         this.applicationsScrollBox = new St.ScrollView({ x_fill: true, y_fill: false,
                                                          y_align: St.Align.START,
-                                                         style_class: 'vfade' });
+                                                         style_class: 'apps-menu vfade' });
         this.applicationsScrollBox.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
         let vscroll = this.applicationsScrollBox.get_vscroll_bar();
         vscroll.connect('scroll-start', Lang.bind(this, function() {
